<template>
  <div class="bbsl-common-page">
    <div class="bbsl-table-content" ref="contentPanel">
      <div class="bbsl-btn-content" ref="btnPanel">
        <!-- <el-button icon="el-icon-plus" type="primary" @click="handleAdd"
    >新增</el-button
  > -->
        <el-button
          type="primary"
          @click="handleRefresh"
          icon="el-icon-refresh"
          style="margin-left: 10px"
        >刷新
        </el-button
        >
      </div>
      <el-table
        border
        size="mini"
        :data="tableData"
        :height="tableMaxHeight"
        :style="{width: '100%'}"
        :cell-style="{'text-align': 'center'}"
        :header-cell-style="{'text-align': 'center'}"
        @selection-change="handleSelectionChange"
      >
        <!-- <el-table-column type="selection" width="55"></el-table-column>
<el-table-column
  fixed
  type="index"
  width="55"
  label="序号"
></el-table-column> -->
        <el-table-column
          fixed
          sortable
          prop="deviceCode"
          label="设备标识"
          show-overflow-tooltip
        ></el-table-column>
        <el-table-column
          fixed
          sortable
          prop="deviceName"
          label="设备名称"
          show-overflow-tooltip
        ></el-table-column>
        <el-table-column
          sortable
          prop="startTime"
          label="状态开始时间"
          show-overflow-tooltip
        ></el-table-column>
        <el-table-column
          sortable
          prop="endTime"
          label="状态结束时间"
          show-overflow-tooltip
        >
        </el-table-column>
        <el-table-column
          prop="timeLength"
          label="状态时长"
          show-overflow-tooltip
        >
        </el-table-column>
        <el-table-column
          min-width="60"
          sortable
          prop="deviceStatusName"
          label="设备状态"
          show-overflow-tooltip
        >
        </el-table-column>
      </el-table>
      <el-pagination
        align="right"
        background
        ref="paginationPanel"
        @size-change="handleSizeChange"
        @current-change="handleCurrentChange"
        :current-page="queryParam.pageBean.page"
        :page-sizes="[20, 30, 40, 50]"
        :page-size="queryParam.pageBean.pageSize"
        layout="total, sizes, prev, pager, next, jumper"
        :total="total"
      ></el-pagination>
    </div>
    <EquipStatuslogDialog ref="formModal"></EquipStatuslogDialog>
  </div>
</template>

<script>
import {TableMixin} from '@/mixins/tableMixin'
import VideoFacilities from '@/api/device/VideoFacilities.js'
import dictUtils from '@/components/dict/DictSelectUtils.js'
import EquipStatuslogDialog from './EquipStatuslogDialog.vue'

export default {
  name: 'VideoStatuslog',
  components: {
    EquipStatuslogDialog
  },
  mixins: [TableMixin],
  props: {
    parameter: {
      type: Object,
      default: function() {
        return
      }
    }
  },
  data() {
    return {
      url: {
        delete: '/deviceStatusLog/v1/'
      }, // 删除状态日志
      deviceStatusList: [], //设备状态字段
      querys: [
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'deviceCode',
          relation: 'AND',
          value: this.parameter.code
        }
      ],
      queryParam: {
        sorter: [
          {
            direction: 'DESC',
            property: 'startTime'
          }
        ]
      }
    }
  },
  created() {
    this.deviceStatusList = dictUtils.getDictItemsFromCache('sbzt')
  },
  mounted() {
  },
  methods: {
    handleRefresh() {
      this.loadData(1)
    },
    handleAdd() {
      this.$refs.formModal.add(this.parameter)
    },
    loadData(page) {
      if (page) {
        this.queryParam.pageBean.page = page
      }
      this.loading = true
      this.tableData = []
      this.queryParam.querys = []
      if (this.querys[0].value) {
        this.queryParam.querys.push(this.querys[0])
      }
      VideoFacilities.loadLog(this.queryParam, (res) => {
        this.total = res.total
        this.loading = false
        res.rows.forEach((item) => {
          this.deviceStatusList.forEach((val) => {
            if (item.deviceStatus == val.value) {
              item['deviceStatusName'] = val.name
            }
          })
          item.timeLength = this.formatMinite(item.timeLength)
        })
        this.tableData = res.rows
        this.$set(this.tableData)
      })
    },
    formatMinite(value) {
      let unit1 = '',
        unit2 = '',
        unit3 = '',
        day = 0,
        hour = 0,
        minite = 0,
        result = ''
      if (value === 0) {
        result = value + '分钟'
      } else if (value < 120) {
        unit1 = '分钟'
        result = value + unit1
      } else if (value >= 120 && value < 24 * 60 * 2) {
        unit1 = '小时'
        unit2 = '分钟'
        hour = parseInt(value / 60)
        minite = value % 60
        result = hour + unit1 + (minite > 0 ? minite + unit2 : '')
      } else if (value >= 24 * 60 * 2) {
        unit1 = '天'
        unit2 = '小时'
        unit3 = '分钟'
        day = parseInt(value / (24 * 60))
        hour = parseInt((value - 24 * 60 * 2) / 60)
        minite = value % 60
        result =
          day +
          unit1 +
          (hour > 0 ? hour + unit2 : '') +
          (minite > 0 ? minite + unit3 : '')
      } else {
        result = value
      }
      return result
    }
  }
}
</script>
<style lang="scss" scoped>
.type-tag {
  margin: 0 2px;
}

.title-box {
  display: flex;
  padding: 10px 0;

  .title {
    font-weight: 600;
  }

  .bule {
    color: #1289fd;
  }
}

::v-deep .el-table {
  height: 100% !important;
}

::v-deep .bbsl-table-content {
  box-shadow: 0px 0px 0 0;
  margin-top: 0px;
  padding: 0px;
}
</style>
